==> haskell-project-template-0.2.1.0-500-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-7qmFbUqZ5A34kgT54gbzBz
key:                  project-template-0.2.1.0-7qmFbUqZ5A34kgT54gbzBz
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  23baaacb5c38579cfb824f48d78e4020
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-7qmFbUqZ5A34kgT54gbzBz
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    bytestring-0.11.5.3 conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    conduit-extra-1.3.8-E4AHXAfmerjKj7JfHrF3lm containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.1.0-501-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-9hbVFYsOwWq6cA49U23QYs
key:                  project-template-0.2.1.0-9hbVFYsOwWq6cA49U23QYs
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  76df5aabc9ec329739a7fcd38f220b0c
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-9hbVFYsOwWq6cA49U23QYs
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
